/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @flow strict-local
 * @format
 */

"use strict";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return typeof key === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (typeof input !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (typeof res !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
const jso = require("javascript-obfuscator");
const composer = require("multi-stage-sourcemap").transfer;
function obfuscator(options) {
  const {
    config
  } = options;
  const isFiltered = !!config.filter && config.filter(options.filename);
  const isNMFile = options.filename.indexOf("node_modules") >= 0;
  const includeNM = isNMFile && (config.includeNodeModules ?? true) === true;
  if (!config.defaultMinifierPath || isFiltered || includeNM || !isNMFile) {
    if (config.trace) {
      console.log("Obfuscating " + options.filename);
    }
    return runJSO(options);
  }
  if (config.trace) {
    console.log("Skip obfuscating " + options.filename);
  }
  return require(config.defaultMinifierPath)(_objectSpread(_objectSpread({}, options), {}, {
    config: config.defaultMinifierConfig ?? {}
  }));
}
function runJSO(options) {
  const result = obfuscate(options);
  if (!options.map || result.map == null) {
    return {
      code: result.code
    };
  }
  const map = JSON.parse(composer({
    fromSourceMap: JSON.parse(result.map),
    toSourceMap: options.map
  }));
  map["sources"] = [options.filename];
  return {
    code: result.code,
    map
  };
}
function obfuscate({
  code,
  reserved,
  config,
  filename
}) {
  const result = jso.obfuscate(code, _objectSpread({
    sourceMap: true,
    inputFileName: filename,
    stringArray: false,
    compact: true,
    controlFlowFlattening: true,
    controlFlowFlatteningThreshold: 0.75,
    identifierNamesGenerator: "hexadecimal",
    numbersToExpressions: true,
    splitStrings: true,
    splitStringsChunkLength: 3,
    transformObjectKeys: true,
    simplify: true,
    disableConsoleOutput: true,
    log: false,
    selfDefending: true,
    unicodeEscapeSequence: true
  }, config));
  return {
    code: result.getObfuscatedCode(),
    map: result.getSourceMap()
  };
}
module.exports = obfuscator;